@@ -257,4 +257,6 @@ def watermark_processor(image, WATERMARK=False, **kwargs):
                     WATERMARK.get('greyscale', False),
                     WATERMARK.get('rotation', 0)
         )
+        if WATERMARK.get('noalpha', False):
+            image = image.convert('RGB')
     return image
